import { useState } from "react";
import {
	Box,
	Button,
	Typography,
	TextField,
	Modal,
	IconButton,
} from "@mui/material";
import CloseIcon from "@mui/icons-material/Close";

export default function AddVehicleModal({
	open,
	handleClose,
	handleAddVehicle,
}) {
	// State for input fields
	const [name, setName] = useState("");
	const [company, setCompany] = useState("");
	const [modelName, setModelName] = useState("");
	const [chargeType, setChargeType] = useState("");
	const [imageUrl, setImageUrl] = useState("");

	const handleSubmit = () => {
		if (!name || !company || !modelName || !chargeType || !imageUrl) {
			alert("Please fill all fields");
			return;
		}

		const newVehicle = {
			name,
			company,
			modelName,
			chargeType,
			imageUrl,
		};

		handleAddVehicle(newVehicle); // Add vehicle to table
		handleClose(); // Close modal after adding
	};

	return (
		<Modal
			open={open}
			onClose={handleClose}
			aria-labelledby="add-vehicle-modal"
		>
			<Box
				sx={{
					position: "absolute",
					top: "50%",
					left: "50%",
					transform: "translate(-50%, -50%)",
					width: 400,
					bgcolor: "background.paper",
					boxShadow: 24,
					p: 3,
					borderRadius: 2,
				}}
			>
				{/* Header */}
				<Box
					sx={{
						display: "flex",
						justifyContent: "space-between",
						alignItems: "center",
					}}
				>
					<Typography variant="h6" fontWeight={600}>
						Add Vehicle
					</Typography>
					<IconButton onClick={handleClose}>
						<CloseIcon />
					</IconButton>
				</Box>

				{/* Horizontal Line */}
				<Box sx={{ borderBottom: "1px solid #ddd", my: 2 }} />

				{/* Input Fields */}
				<Box sx={{ display: "flex", flexDirection: "column", gap: 2 }}>
					{/* First Row - Two Inputs */}
					<Box sx={{ display: "flex", gap: 2 }}>
						<Box
							sx={{
								display: "flex",
								flexDirection: "column",
								width: "100%",
							}}
						>
							<Typography variant="body2" fontWeight={500}>
								Vehicle Name
							</Typography>
							<TextField
								fullWidth
								placeholder="Enter Vehicle Name"
								size="small"
								value={name}
								onChange={(e) => setName(e.target.value)}
							/>
						</Box>

						<Box
							sx={{
								display: "flex",
								flexDirection: "column",
								width: "100%",
							}}
						>
							<Typography variant="body2" fontWeight={500}>
								Company
							</Typography>
							<TextField
								fullWidth
								placeholder="Enter Company Name"
								size="small"
								value={company}
								onChange={(e) => setCompany(e.target.value)}
							/>
						</Box>
					</Box>

					{/* Second Row - Two Inputs */}
					<Box sx={{ display: "flex", gap: 2 }}>
						<Box
							sx={{
								display: "flex",
								flexDirection: "column",
								width: "100%",
							}}
						>
							<Typography variant="body2" fontWeight={500}>
								Model Name
							</Typography>
							<TextField
								fullWidth
								placeholder="Enter Model Name"
								size="small"
								value={modelName}
								onChange={(e) => setModelName(e.target.value)}
							/>
						</Box>

						<Box
							sx={{
								display: "flex",
								flexDirection: "column",
								width: "100%",
							}}
						>
							<Typography variant="body2" fontWeight={500}>
								Charge Type
							</Typography>
							<TextField
								fullWidth
								placeholder="Enter Charge Type"
								size="small"
								value={chargeType}
								onChange={(e) => setChargeType(e.target.value)}
							/>
						</Box>
					</Box>

					{/* Third Row - Image URL */}
					<Box
						sx={{
							display: "flex",
							flexDirection: "column",
							width: "100%",
						}}
					>
						<Typography variant="body2" fontWeight={500}>
							Image URL
						</Typography>
						<TextField
							fullWidth
							placeholder="Enter Image URL"
							size="small"
							value={imageUrl}
							onChange={(e) => setImageUrl(e.target.value)}
						/>
					</Box>
				</Box>

				{/* Submit Button */}
				<Box
					sx={{ display: "flex", justifyContent: "flex-end", mt: 3 }}
				>
					<Button variant="contained" onClick={handleSubmit}>
						Add Vehicle
					</Button>
				</Box>
			</Box>
		</Modal>
	);
}
